#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-

"An OpenID login example with some local user pages."

from WebStack.Resources.OpenIDLogin import OpenIDLoginResource, Authenticator
from WebStack.Resources.ResourceMap import MapResource
from WebStack.Resources.Static import StringResource
from WebStack.Generic import ContentType
import urllib

def get_site_map(app_url, deployment_url):

    """
    Return a resource for the site having the given 'app_url' and
    'deployment_url'. The 'app_url' should be the "bare" reference using a
    protocol, host and port, not including any path information.
    """

    # NOTE: Support "special" username due to stupid HTML 4 restrictions.

    special_username = urllib.quote(u"".encode("utf-8"))

    login = OpenIDLoginResource(
        app_url=app_url,
        authenticator=Authenticator(
            credentials=(
                # Local identifier, username, password
                ((deployment_url +  "/badger",  "badger"), "abc"),
                ((deployment_url +  "/vole",    "vole"),   "xyz"),
                ((deployment_url + u"/",    u""),   u""),
                ((deployment_url +  "/badger2", "badger"), "abc"),
                ((deployment_url +  "/vole2",   "vole"),   "xyz"),
                ((deployment_url + u"/2",   u""),   u""),
                ((deployment_url +  "/" + special_username, u""), u""),
                )
            )
        )

    return MapResource({
        "" : login,
        "login" : login,

        # Some local OpenID pages.

        "badger" :
            StringResource("""
                <html>
                  <head>
                    <meta http-equiv="Content-Type" content="text/html; charset="iso-8859-1" />
                    <link rel="openid2.provider openid.server" href="%s/login" />
                    <link rel="openid2.local_id openid.delegate" href="%s/badger" />
                    <title>Badger's Home Page</title>
                  </head>
                  <body>
                    <p>Home page for the OpenID authenticated user, <code>badger</code>.</p>
                  </body>
                </html>
            """ % (deployment_url, deployment_url), ContentType("text/html")),
        u"" :
            StringResource(u"""
                <html>
                  <head>
                    <meta http-equiv="Content-Type" content="text/html; charset="iso-8859-1" />
                    <link rel="openid2.provider openid.server" href="%s/login" />
                    <link rel="openid2.local_id openid.delegate" href="%s/%s" />
                    <title>Home Page for </title>
                  </head>
                  <body>
                    <p>Home page for the OpenID authenticated user, <code></code>.</p>
                  </body>
                </html>
            """ % (deployment_url, deployment_url, special_username), ContentType("text/html", "iso-8859-1")),
        "vole" :
            StringResource("""
                <html>
                  <head>
                    <meta http-equiv="Content-Type" content="text/html; charset="iso-8859-1" />
                    <link rel="openid2.provider openid.server" href="%s/login" />
                    <link rel="openid2.local_id openid.delegate" href="%s/vole" />
                    <title>Vole's Home Page</title>
                  </head>
                  <body>
                    <p>Home page for the OpenID authenticated user, <code>vole</code>.</p>
                  </body>
                </html>
            """ % (deployment_url, deployment_url), ContentType("text/html")),

        # OpenID 2.0 resources.
        # See: http://docs.oasis-open.org/xri/2.0/specs/cd02/xri-resolution-V2.0-cd-02.html#_Ref129424065
        #      ("3.3 Media Types for XRI Resolution")
        # See: http://openid.net/specs/openid-authentication-2_0.html#discovery
        #      ("7.3. Discovery")

        "badger2" :
            StringResource("""
                <?xml version="1.0"?>
                <Service xmlns="xri://$xrd*($v*2.0)">
                  <Type>http://specs.openid.net/auth/2.0/signon</Type>
                  <URI>%s/login</URI>
                  <LocalID>%s/badger2</LocalID>
                </Service>
            """ % (deployment_url, deployment_url), ContentType("application/xrd+xml")),
        u"2" :
            StringResource(u"""
                <?xml version="1.0" encoding="iso-8859-1"?>
                <Service xmlns="xri://$xrd*($v*2.0)">
                  <Type>http://specs.openid.net/auth/2.0/signon</Type>
                  <URI>%s/login</URI>
                  <LocalID>%s/2</LocalID>
                </Service>
            """ % (deployment_url, deployment_url), ContentType("application/xrd+xml", "iso-8859-1")),
        "vole2" :
            StringResource("""
                <?xml version="1.0"?>
                <Service xmlns="xri://$xrd*($v*2.0)">
                  <Type>http://specs.openid.net/auth/2.0/signon</Type>
                  <URI>%s/login</URI>
                  <LocalID>%s/vole2</LocalID>
                </Service>
            """ % (deployment_url, deployment_url), ContentType("application/xrd+xml")),
        })

# vim: tabstop=4 expandtab shiftwidth=4
